summaryrefslogtreecommitdiffstats
path: root/Source/cmake.cxx
diff options
context:
space:
mode:
authorBill Hoffman <bill.hoffman@kitware.com>2001-06-13 21:03:49 (GMT)
committerBill Hoffman <bill.hoffman@kitware.com>2001-06-13 21:03:49 (GMT)
commit78ee6660a7ecffcf4123bda9397d37869fb9deac (patch)
treef8035125574b7f8cfbdd4b84348838128bcdeec6 /Source/cmake.cxx
parentf6f8dde5a8cb25ab190987da3c959a58977b2d7d (diff)
downloadCMake-78ee6660a7ecffcf4123bda9397d37869fb9deac.zip
CMake-78ee6660a7ecffcf4123bda9397d37869fb9deac.tar.gz
CMake-78ee6660a7ecffcf4123bda9397d37869fb9deac.tar.bz2
ENH: fix EXECUTABLE_OUTPUT_PATH and LIBRARY_OUTPUT_PATH for unix
Diffstat (limited to 'Source/cmake.cxx')
-rw-r--r--Source/cmake.cxx15
1 files changed, 14 insertions, 1 deletions
diff --git a/Source/cmake.cxx b/Source/cmake.cxx
index 4577ba8..8d782af 100644
--- a/Source/cmake.cxx
+++ b/Source/cmake.cxx
@@ -129,11 +129,24 @@ void cmake::SetArgs(cmMakefile& builder, const std::vector<std::string>& args)
// at the end of this CMAKE_ROOT and CMAAKE_COMMAND should be added to the cache
void cmake::AddCMakePaths(const std::vector<std::string>& args)
{
// Find our own exectuable.
std::string cMakeSelf = args[0];
cmSystemTools::ConvertToUnixSlashes(cMakeSelf);
cMakeSelf = cmSystemTools::FindProgram(cMakeSelf.c_str());
+ if(!cmCacheManager::GetInstance()->GetCacheValue("LIBRARY_OUTPUT_PATH"))
+ {
+ cmCacheManager::GetInstance()->AddCacheEntry("LIBRARY_OUTPUT_PATH", "",
+ "Single output directory for building all libraries.",
+ cmCacheManager::PATH);
+ }
+ if(!cmCacheManager::GetInstance()->GetCacheValue("EXECUTABLE_OUTPUT_PATH"))
+ {
+ cmCacheManager::GetInstance()->AddCacheEntry("EXECUTABLE_OUTPUT_PATH", "",
+ "Single output directory for building all executables.",
+ cmCacheManager::PATH);
+ }
+
// Save the value in the cache
cmCacheManager::GetInstance()->AddCacheEntry
("CMAKE_COMMAND",
@@ -129,11 +129,24 @@ void cmake::SetArgs(cmMakefile& builder, const std::vector<std::string>& args)
void cmake::AddCMakePaths(const std::vector<std::string>& args)
{
- // Find our own exectuable.
+ // Find our own executable.
std::string cMakeSelf = args[0];
cmSystemTools::ConvertToUnixSlashes(cMakeSelf);